function [sys,x0] = incins(t,x,u,flag)

% Inputs:    t    - time in [s].
%            X    - States. A total of 3*N states.
%                   Temperatures of cold side gas, hot side gas and heat
%                   exchanger wall elements
%            U(1) - Inlet cold gas temperature, Tc0 [K]
%            U(2) - Inlet hot gas temperature, Th0 [K]
%            U(3) - Mass flow [kg/s], m
%            U(4) - Hot side bypass , a
% Outputs:   sys and x0 as described in the SIMULINK manual.
%            when flag is 0 sys contains sizes and x0 contains 
%            initial condition. 
%            when flag is 1, sys contains the derivatives,
%            and when flag is 3 sys contains outputs; 


N=10;
Xinit=[ones(N,1)*400; ones(N,1)*5; ones(N,1)*250];
if abs(flag) == 1
  % Return state derivatives.
  sys = HEX(t,x,u);
elseif abs(flag) == 3
  % Return system outputs.
  sys(1,1) = x(2*N);          % Outlet temp. cold side
elseif flag == 0
  % Ininitalize the system
  x0 = Xinit;
  sys = [3*N, 0, 1, 4, 0, 0];
else
  sys = [];  
end
  
