function dTdt=incin(t,X,U)



% Inputs:    t    - time in [s].
%            X    - States. A total of 2*N states.
%                   Temperatures of gas (1-N) and catalyst (N+1 -
%                   2*N) in each mixing tank
%            U(1) - Inlet gas temperature, T0 [K]
%            U(2) - Mass flow gas [kg/s]
%            U(3) - massfrac of VOC 

% Outputs:   sys and x0 as described in the SIMULINK manual.
%            when flag is 0 sys contains sizes and x0 contains 
%            initial condition. 
%            when flag is 1, sys contains the derivatives,
%            and when flag is 3 sys contains outputs; 
%            y(1:N)    - Gas temperature in element N [K]
%            y(N+1:2*N)- Catalyst temperature in element N [K]

N=10;


Cpcat   =   800;
UAcat   =   1000;
UAwall  =   0.01;
Tamb    =   15;
mcat    =   280;
kAcat   =   100;

deltaHc =   35000000; %[J/kg]
Vg      =   0.5;
Cpg     =   1013;
P=1;
M=0.029;
R=8.2057*10^-5;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T=X(1:2*N)';                          

% Inputs and disturbances
T0      = U(1);                             % Inlet temp.
m       = U(2);                             % Mass flow of gas
w       = U(3);                             % Mass fraction of VOC

% T(1:N) is the gas temperature
% T(N+1:2*N) is the catalyst temperature

%%% ~~~~~~~~~~~~~~  Model ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

% Initial elements 
dTdt(1)=    (((N*m*R*(T(1)+273.15))/(P*M*Vg))*(T0-T(1)))...           
            -((UAcat*R*(T(1)+273.15)/(P*M*Vg*Cpg))*(T(1)-(T(N+1))));
        
dTdt(N+1)=  (UAcat/(mcat*Cpcat)*(T(1)-T(N+1)))...
            +((kAcat*N/(mcat*Cpcat))*(T(N+2)-T(N+1))) -(UAwall/(mcat*Cpcat))*(T(N+1)-(Tamb));

% Interior elements   
for i=2:(N-1)
    if T(i)>=270 % ignition tempereature exceeded   
        dTdt(i)=    (((N*m*R*(T(i)+273.15))/(P*M*Vg))*(T(i-1)-T(i)))...
                    -((UAcat*R*(T(i)+273.15)/(P*M*Vg*Cpg))*(T(i)-(T(N+i))))...
                    +(m*w*deltaHc*N*R*(T(i)+273.15)/(P*M*Vg*Cpg));
                    w=0;
    else %below ignition temperature
        dTdt(i)=    (((N*m*R*(T(i)+273.15))/(P*M*Vg))*(T(i-1)-T(i)))...
                    -((UAcat*R*(T(i)+273.15)/(P*M*Vg*Cpg))*(T(i)-(T(N+i))));
    end
        dTdt(N+i)=  (UAcat/(mcat*Cpcat)*(T(i)-T(N+i))) + (kAcat*N/(mcat*Cpcat))*(T(N+i-1)+T(i+N+1)-2*T(N+i))...
                    -(UAwall/(mcat*Cpcat))*(T(N+i)-(Tamb));
end
 
% Final elements
    dTdt(N)=    (((N*m*R*(T(N)+273.15))/(P*M*Vg))*(T(N-1)-T(N)))...
                -((UAcat*R*(T(N)+273.15)/(P*M*Vg*Cpg))*(T(N)-T(2*N)));         
    dTdt(2*N)=  (UAcat/(mcat*Cpcat)*(T(N)-T(2*N)))    +((kAcat*N/(mcat*Cpcat))*(T((2*N)-1)-T(2*N)))...
                -(UAwall/(mcat*Cpcat))*(T(2*N)-(Tamb));   % Catalyst



 