function [sys,x0] = incins(t,x,u,flag)

% Inputs:    t    - time in [s].
%            X    - States. A total of 2*N states.
%                   Temperatures of gas (1-N) and catalyst (N+1 -
%                   2*N) in each mixing tank
%            U(1) - Inlet gas temperature, T0 [K]
%            U(2) - Massflow of gas [kg/s]
%            U(3) - Massfrac of VOC

% Outputs:   sys and x0 as described in the SIMULINK manual.
%            when flag is 0 sys contains sizes and x0 contains 
%            initial condition. 
%            when flag is 1, sys contains the derivatives,
%            and when flag is 3 sys contains outputs; 
%            y(1:N)    - Gas temperature in element N [K]
%            y(N+1:2*N)- Catalyst temperature in element N [K]

N=10;
Xinit=[ones(N,1)*250; ones(N,1)*350];
if abs(flag) == 1
  % Return state derivatives.
  sys = incin(t,x,u);
elseif abs(flag) == 3
  % Return system outputs.
  sys(1,1) = x(1);         % Gas temperature in element 1.
  sys(2,1) = x(N);         % Gas temperature in element N.
elseif flag == 0
  % Ininitalize the system
  x0 = Xinit;
  sys = [2*N, 0, 2, 3, 0, 0];
else
  sys = [];  
end
  
